       subroutine stebj1(n,fj,fmean,fjm,fmm,fv,fe) 
c                                                                     
c    bernd berg april 6 1991.
c    purpose: calculation of the jackknife estimators fjm  and
c             the unbiased estimator fmm for  the mean value <f>,
c             jackknife estimator fv for the variance <f*f>-<f><f>,
c             and error bar, defined as standard deviation of fjm
c             fe  := sqrt(fmv) = sqrt(fv/n).   
c                                                                     
c    input:
c                                                                     
c    n       number of measurements;  n > 1;
c    fj      vector containing the measurements to be averaged;    
c    fmean   mean value from complete statistics.
c
c    output:
c
c    fjm     jackknife  mean value;
c    fmm     unbiased mean values;
c    fv      variance;            
c    fe      error bar.
c                                                                     
      include '../../libs/fortran/implicit.sta'
      dimension fj(n)
      if(n.lt.2) stop 'stebj1: n too small!'
      call stebj0(n,fj,fjm,fv,fe)
      call bias(n,fj,fmean,fmm,biasm)
      return
      end
